package
Version:
v1.20.13
Opens a new window with list of versions in this module.
Published: Apr 28, 2026
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type WebError struct {
Errcode int `json:"errcode,omitempty"`
Errmsg string `json:"errmsg,omitempty"`
Errparam map[string]interface{} `json:"errparam,omitempty"`
}
WebError
Source Files
¶
Click to show internal directories.
Click to hide internal directories.