package
Version:
v1.0.9
Opens a new window with list of versions in this module.
Published: Sep 12, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type MpPhoneReq struct {
Code string `json:"code,omitempty"`
}
MpPhoneReq
type State struct {
NickName string `json:"nickName,omitempty"`
Ok bool `json:"ok,omitempty"`
}
State
type Ticket struct {
State string `json:"state,omitempty"`
}
Ticket
Source Files
¶
Click to show internal directories.
Click to hide internal directories.